# rovel.py

## Install
```bat
pip install rovel.py
```
```bat
python -m pip install rovel.py
```

## Usage:
```py
from rolve.api_npm import *

print(get_details("rolve.js"))
```

## List of packages:
- colorama
- approx
- emoji
- api-npm
- pydash
- requests
- aiohttp